@@ -55,9 +55,9 @@ use std::io::BufReader;
 #[derive(Debug, thiserror::Error)]
 #[error("Acceptor error")]
 pub enum Error {
-    #[error("I/O {0}")]
+    #[error("I/O: {0}")]
     Io(#[from] io::Error),
-    #[error("Connection error {0}")]
+    #[error("Connection error: {0}")]
     Connection(#[from] remotelink::Error),
     #[error("Timeout")]
     Timeout(#[from] Elapsed),
@@ -66,10 +66,10 @@ pub enum Error {
     #[error("Channel send error")]
     Send(#[from] SendError<(Id, Event)>),
     #[cfg(feature = "use-native-tls")]
-    #[error("Native TLS error {0}")]
+    #[error("Native TLS error: {0}")]
     NativeTls(#[from] NativeTlsError),
     #[cfg(feature = "use-rustls")]
-    #[error("Rustls error {0}")]
+    #[error("Rustls error: {0}")]
     Rustls(#[from] RustlsError),
     #[error("Server cert not provided")]
     ServerCertRequired,
@@ -81,18 +81,19 @@ pub enum Error {
     ServerCertNotFound(String),
     #[error("Server private key file {0} not found")]
     ServerKeyNotFound(String),
-    #[error("Invalid CA cert file {0}")]
+    #[error("Invalid CA cert file: {0}")]
     InvalidCACert(String),
-    #[error("Invalid server cert file {0}")]
+    #[error("Invalid server cert file: {0}")]
     InvalidServerCert(String),
     #[error("Invalid server pass")]
-    InvalidServerPass(),
-    #[error("Invalid server key file {0}")]
+    InvalidServerPass,
+    #[error("Invalid server key file: {0}")]
     InvalidServerKey(String),
     RustlsNotEnabled,
     NativeTlsNotEnabled,
     Disconnected,
     NetworkClosed,
+    #[error("Wrong packet: {0:?}")]
     WrongPacket(Packet),
 }
 
@@ -269,23 +270,23 @@ impl Server {
     #[cfg(feature = "use-native-tls")]
     fn tls_native_tls(
         &self,
-        pkcs12_path: &String,
-        pkcs12_pass: &String,
+        pkcs12_path: &str,
+        pkcs12_pass: &str,
     ) -> Result<Option<ServerTLSAcceptor>, Error> {
         // Get certificates
         let cert_file = File::open(&pkcs12_path);
         let mut cert_file =
-            cert_file.map_err(|_| Error::ServerCertNotFound(pkcs12_path.clone()))?;
+            cert_file.map_err(|_| Error::ServerCertNotFound(pkcs12_path.to_string()))?;
 
         // Read cert into memory
         let mut buf = Vec::new();
         cert_file
             .read_to_end(&mut buf)
-            .map_err(|_| Error::InvalidServerCert(pkcs12_path.clone()))?;
+            .map_err(|_| Error::InvalidServerCert(pkcs12_path.to_string()))?;
 
         // Get the identity
-        let identity = native_tls::Identity::from_pkcs12(&buf, &pkcs12_pass)
-            .map_err(|_| Error::InvalidServerPass())?;
+        let identity = native_tls::Identity::from_pkcs12(&buf, pkcs12_pass)
+            .map_err(|_| Error::InvalidServerPass)?;
 
         // Builder
         let builder = native_tls::TlsAcceptor::builder(identity).build()?;
@@ -369,9 +370,9 @@ impl Server {
     #[cfg(not(feature = "use-rustls"))]
     fn tls_rustls(
         &self,
-        _cert_path: &String,
-        _key_path: &String,
-        _ca_path: &String,
+        _cert_path: &str,
+        _key_path: &str,
+        _ca_path: &str,
     ) -> Result<Option<ServerTLSAcceptor>, Error> {
         Err(Error::RustlsNotEnabled)
     }
