@@ -9,10 +9,10 @@ use std::vec::IntoIter;
 
 #[derive(Debug, thiserror::Error)]
 pub enum Error {
-    #[error("Received unsolicited ack from the device. {0}")]
+    #[error("Received unsolicited ack from the device: {0}")]
     Unsolicited(u16),
-    #[error("Collision with an unacked packet")]
-    Serialization(mqttbytes::Error),
+    #[error("Collision with an unacked packet: {0}")]
+    Serialization(#[from] mqttbytes::Error),
     #[error("Collision with an unacked packet")]
     Collision,
     #[error("Duplicate connect")]
@@ -23,12 +23,6 @@ pub enum Error {
     Disconnect,
 }
 
-impl From<mqttbytes::Error> for Error {
-    fn from(e: mqttbytes::Error) -> Error {
-        Error::Serialization(e)
-    }
-}
-
 #[derive(Debug)]
 struct Pending {
     topic: String,
